.. Metasyn documentation master file, created by
   sphinx-quickstart on Thu May 12 14:26:19 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. |break| raw:: html

   <br />


.. image:: /images/logos/blue.svg
   :alt: Metasyn

|break|

``Metasyn`` is a python package for generating synthetic data with a focus on maintaining privacy.
It is aimed at owners of sensitive datasets such as public organisations, research groups, and individual researchers who
want to improve the accessibility, reproducibility and reusability of their data. The goal of metasyn is to make it easy
for data owners to share the structure and approximation of the content of their data with others with fewer privacy concerns.


.. image:: https://img.shields.io/badge/GitHub-blue?logo=github&link=https%3A%2F%2Fgithub.com%2Fsodascience%2Fmetasyn
   :alt: GitHub Repository Button
   :target: https://github.com/sodascience/metasyn

.. image:: https://img.shields.io/badge/GitHub-Issue_Tracker-blue?logo=github&link=https%3A%2F%2Fgithub.com%2Fsodascience%2Fmetasyn%2Fissues
   :alt: GitHub Issue Tracker Button
   :target: https://github.com/sodascience/metasyn/issues
   


.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Getting started

   what_is_metasyn
   installation
   quick_start
   tutorials


.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Usage

   improve_synth
   datafree

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Advanced usage

   cli
   developer/developer
   api/metasyn
   plugins

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Extras

   faq
   about
